@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -37,7 +37,7 @@ QWidget *SieveActionExtractText::createParamWidget(QWidget *parent) const
     nbCharacters->setMaximum(99999);
     nbCharacters->setObjectName(QStringLiteral("numberOfCharacters"));
     grid->addWidget(nbCharacters, 0, 1);
-    connect(nbCharacters, QOverload<int>::of(&QSpinBox::valueChanged), this, &SieveActionExtractText::valueChanged);
+    connect(nbCharacters, &QSpinBox::valueChanged, this, &SieveActionExtractText::valueChanged);
 
     lab = new QLabel(i18n("Stored in variable name:"));
     grid->addWidget(lab, 1, 0);
@@ -54,7 +54,11 @@ QWidget *SieveActionExtractText::createParamWidget(QWidget *parent) const
 void SieveActionExtractText::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, QString &error)
 {
     while (element.readNextStartElement()) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         const QStringRef tagName = element.name();
+#else
+        const QStringView tagName = element.name();
+#endif
 
         if (tagName == QLatin1String("tag")) {
             element.skipCurrentElement();
