@@ -1,25 +1,22 @@
 /*
-  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "managesievescriptsdialog.h"
 #include "editor/sieveeditor.h"
-#include "editor/sievetextedit.h"
 #include "managescriptsjob/checkscriptjob.h"
 #include "widgets/custommanagesievewidget.h"
-#include "widgets/managesievetreeview.h"
-#include "widgets/sievetreewidgetitem.h"
 
 #include "util/sieveimapaccountsettings.h"
 
 #include <KConfigGroup>
 #include <KLocalizedString>
 #include <KMessageBox>
+#include <QHideEvent>
 #include <QPushButton>
 
-#include "libksieve_debug.h"
 #include <kmanagesieve/sievejob.h>
 
 #include <QTreeWidget>
@@ -54,6 +51,11 @@ public:
     bool mWasActive = false;
 };
 
+namespace
+{
+static const char myManageSieveScriptsDialog[] = "ManageSieveScriptsDialog";
+}
+
 ManageSieveScriptsDialog::ManageSieveScriptsDialog(SieveImapPasswordProvider *passwordProvider, QWidget *parent)
     : QDialog(parent)
     , d(new KSieveUi::ManageSieveScriptsDialogPrivate)
@@ -99,7 +101,7 @@ ManageSieveScriptsDialog::ManageSieveScriptsDialog(SieveImapPasswordProvider *pa
     connect(close, &QPushButton::clicked, this, &ManageSieveScriptsDialog::accept);
     buttonLayout->addWidget(close);
 
-    KConfigGroup group(KSharedConfig::openStateConfig(), "ManageSieveScriptsDialog");
+    KConfigGroup group(KSharedConfig::openStateConfig(), myManageSieveScriptsDialog);
     const QSize size = group.readEntry("Size", QSize());
     if (size.isValid()) {
         resize(size);
@@ -111,7 +113,7 @@ ManageSieveScriptsDialog::ManageSieveScriptsDialog(SieveImapPasswordProvider *pa
 ManageSieveScriptsDialog::~ManageSieveScriptsDialog()
 {
     disconnect(d->mTreeView, &CustomManageSieveWidget::updateButtons, this, &ManageSieveScriptsDialog::slotUpdateButtons);
-    KConfigGroup group(KSharedConfig::openStateConfig(), "ManageSieveScriptsDialog");
+    KConfigGroup group(KSharedConfig::openStateConfig(), myManageSieveScriptsDialog);
     group.writeEntry("Size", size());
     // prevent QTreeWidget signals triggered by it's destructor from calling our slots
     d->mTreeView->disconnect(this);
